@@ -36,7 +36,10 @@ class QuerySetDescriptor:
         value = instance.__dict__[self.field.name]
         model = getattr(instance, self.field.modelfieldname, None)
         if model and model.model_class():
-            return parsequeryexpression(model.model_class().objects, value)
+            try:
+                return parsequeryexpression(model.model_class().objects, value)
+            except DjangoQLError:
+                pass
         return QueryValue(None, value)
 
     def __set__(self, instance, value):
