@@ -7,6 +7,14 @@ from bread import layout, utils, views
 class WorkflowBrowseView(views.BrowseView):
     rowclickaction = views.BrowseView.gen_rowclickaction("edit")
 
+    def get_queryset(self):
+        return (
+            super()
+            .get_queryset()
+            .exclude(completed__isnull=False)
+            .exclude(cancelled__isnull=False)
+        )
+
     def get_layout(self):
         workflow_diagram = layout.modal.Modal(
             _("Workflow Diagram"),
